@@ -1,4 +1,4 @@
-#!/usr/bin/python3.13
+#!/usr/bin/python3.12
 # coding=utf-8
 #
 # Copyright (c) 2009 Bryan Hoyt (MIT License)
@@ -132,7 +132,7 @@ class PixelSnap(inkex.EffectExtension):
             "--max_gradient",
             type=float,
             default=0.5,
-            help="Maximum slope to consider straight (%)",
+            help="Maximum slope to consider straight (%%)",
         )
         pars.add_argument(
             "-s",
